@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.47 2004/07/30 19:56:08 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.53 2004/08/08 18:11:56 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -70,6 +70,7 @@
 #include "nsIChannel.h"
 
 #ifdef ALLOW_PRIVATE_API
+#include "nsIDocShell.h"
 #include "nsIMarkupDocumentViewer.h"
 #ifdef HAVE_MOZILLA_PSM
 /* not sure about this one: */
@@ -106,16 +107,15 @@ EphyEventListener::Init(EphyEmbed *aOwner)
 nsresult
 EphyFaviconEventListener::HandleFaviconLink (nsIDOMNode *node)
 {
-	nsresult result;
-
 	nsCOMPtr<nsIDOMElement> linkElement;
 	linkElement = do_QueryInterface (node);
 	if (!linkElement) return NS_ERROR_FAILURE;
 
 	PRUnichar relAttr[] = { 'r', 'e', 'l', '\0' };
+	nsresult rv;
 	nsEmbedString value;
-	result = linkElement->GetAttribute (nsEmbedString(relAttr), value);
-	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	rv = linkElement->GetAttribute (nsEmbedString(relAttr), value);
+	if (NS_FAILED (rv)) return NS_ERROR_FAILURE;
 
 	nsEmbedCString rel;
 	NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, rel);	
@@ -125,8 +125,8 @@ EphyFaviconEventListener::HandleFaviconLink (nsIDOMNode *node)
 	{
 		PRUnichar hrefAttr[] = { 'h', 'r', 'e', 'f', '\0' };
 		nsEmbedString value;
-		result = linkElement->GetAttribute (nsEmbedString (hrefAttr), value);
-		if (NS_FAILED (result) || !value.Length()) return NS_ERROR_FAILURE;
+		rv = linkElement->GetAttribute (nsEmbedString (hrefAttr), value);
+		if (NS_FAILED (rv) || !value.Length()) return NS_ERROR_FAILURE;
 
 		nsEmbedCString link;
 		NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, link);
@@ -139,16 +139,16 @@ EphyFaviconEventListener::HandleFaviconLink (nsIDOMNode *node)
 		NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
 
 		nsEmbedString spec;
-		result = doc->GetDocumentURI (spec);
-		NS_ENSURE_SUCCESS (result, result);
+		rv = doc->GetDocumentURI (spec);
+		NS_ENSURE_SUCCESS (rv, rv);
 
 		nsCOMPtr<nsIURI> uri;
-		result = EphyUtils::NewURI (getter_AddRefs(uri), spec);
-		NS_ENSURE_SUCCESS (result, result);
+		rv = EphyUtils::NewURI (getter_AddRefs(uri), spec);
+		NS_ENSURE_SUCCESS (rv, rv);
 
 		nsEmbedCString favicon_url;
-		result = uri->Resolve (link, favicon_url);
-		if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+		rv = uri->Resolve (link, favicon_url);
+		if (NS_FAILED (rv)) return NS_ERROR_FAILURE;
 		
 		char *url = g_strdup (favicon_url.get());
 		g_signal_emit_by_name (mOwner, "ge_favicon", url);
@@ -162,7 +162,6 @@ NS_IMETHODIMP
 EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 {
 	nsCOMPtr<nsIDOMEventTarget> eventTarget;
-
 	aDOMEvent->GetTarget(getter_AddRefs(eventTarget));
 
 	nsCOMPtr<nsIDOMNode> node = do_QueryInterface(eventTarget);
@@ -176,19 +175,17 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 NS_IMETHODIMP
 EphyPopupBlockEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 {
-	nsresult rv;
-
 	NS_ENSURE_TRUE (mOwner != NULL, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsIDOMPopupBlockedEvent> popupEvent =
-		do_QueryInterface (aDOMEvent, &rv);
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+		do_QueryInterface (aDOMEvent);
+	NS_ENSURE_TRUE (popupEvent, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsIURI> popupWindowURI;
-	rv = popupEvent->GetPopupWindowURI (getter_AddRefs (popupWindowURI));
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-	NS_ENSURE_SUCCESS (popupWindowURI != NULL, NS_ERROR_FAILURE);
+	popupEvent->GetPopupWindowURI (getter_AddRefs (popupWindowURI));
+	NS_ENSURE_TRUE (popupWindowURI, NS_ERROR_FAILURE);
 
+	nsresult rv;
 	nsEmbedCString popupWindowURIString;
 	rv = popupWindowURI->GetSpec (popupWindowURIString);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
@@ -214,16 +211,16 @@ EphyBrowser::EphyBrowser ()
 , mPopupBlockEventListener(nsnull)
 , mInitialized(PR_FALSE)
 {
+	LOG ("EphyBrowser ctor (%p)", this)
 }
 
 EphyBrowser::~EphyBrowser ()
 {
+	LOG ("EphyBrowser dtor (%p)", this)
 }
 
 nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 {
-	nsresult rv;
-
 	if (mInitialized) return NS_OK;
 
 	gtk_moz_embed_get_nsIWebBrowser (mozembed,
@@ -234,6 +231,7 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 	NS_ENSURE_TRUE (mDOMWindow, NS_ERROR_FAILURE);
 
 	/* This will instantiate an about:blank doc if necessary */
+	nsresult rv;
 	nsCOMPtr<nsIDOMDocument> domDocument;
 	rv = mDOMWindow->GetDocument (getter_AddRefs (domDocument));
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
@@ -261,7 +259,7 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 nsresult
 EphyBrowser::GetListener (void)
 {
-  	if (mEventReceiver) return NS_ERROR_FAILURE;
+  	if (mEventTarget) return NS_ERROR_FAILURE;
 
   	nsCOMPtr<nsIDOMWindow> domWindowExternal;
   	mWebBrowser->GetContentDOMWindow (getter_AddRefs(domWindowExternal));
@@ -269,11 +267,8 @@ EphyBrowser::GetListener (void)
   	nsCOMPtr<nsIDOMWindow2> domWindow (do_QueryInterface (domWindowExternal));
 	NS_ENSURE_TRUE (domWindow, NS_ERROR_FAILURE);
 	
-  	nsCOMPtr<nsIDOMEventTarget> rootWindow;
-  	domWindow->GetWindowRoot (getter_AddRefs(rootWindow));
-
-  	mEventReceiver = do_QueryInterface (rootWindow);
-	NS_ENSURE_TRUE (mEventReceiver, NS_ERROR_FAILURE);
+  	domWindow->GetWindowRoot (getter_AddRefs(mEventTarget));
+	NS_ENSURE_TRUE (mEventTarget, NS_ERROR_FAILURE);
 
 	return NS_OK;
 }
@@ -281,19 +276,13 @@ EphyBrowser::GetListener (void)
 nsresult
 EphyBrowser::AttachListeners(void)
 {
+	NS_ENSURE_TRUE (mEventTarget, NS_ERROR_FAILURE);
+
 	nsresult rv;
-
-	NS_ENSURE_TRUE (mEventReceiver, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDOMEventTarget> target;
-	target = do_QueryInterface (mEventReceiver);
-
-	rv = target->AddEventListener(nsEmbedString(DOMLinkAdded),
-				      mFaviconEventListener, PR_FALSE);
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-
-	rv = target->AddEventListener(nsEmbedString(DOMPopupBlocked),
-				      mPopupBlockEventListener, PR_FALSE);
+	rv = mEventTarget->AddEventListener(nsEmbedString(DOMLinkAdded),
+					    mFaviconEventListener, PR_FALSE);
+	rv |= mEventTarget->AddEventListener(nsEmbedString(DOMPopupBlocked),
+					     mPopupBlockEventListener, PR_FALSE);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	return NS_OK;
@@ -302,21 +291,15 @@ EphyBrowser::AttachListeners(void)
 nsresult
 EphyBrowser::DetachListeners(void)
 {
+	if (!mEventTarget) return NS_OK;
+
 	nsresult rv;
-
-	if (!mEventReceiver) return NS_OK;
-
-	nsCOMPtr<nsIDOMEventTarget> target;
-	target = do_QueryInterface (mEventReceiver);
-	NS_ENSURE_TRUE (target, NS_ERROR_FAILURE);
-
-	rv = target->RemoveEventListener(nsEmbedString(DOMLinkAdded),
-					 mFaviconEventListener, PR_FALSE);
+	rv = mEventTarget->RemoveEventListener(nsEmbedString(DOMLinkAdded),
+					       mFaviconEventListener, PR_FALSE);
+	rv |= mEventTarget->RemoveEventListener(nsEmbedString(DOMPopupBlocked),
+					        mPopupBlockEventListener, PR_FALSE);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-	rv = target->RemoveEventListener(nsEmbedString(DOMPopupBlocked),
-					 mPopupBlockEventListener, PR_FALSE);
-
 	return NS_OK;
 }
 
@@ -390,15 +373,13 @@ nsresult EphyBrowser::PrintPreviewNavigate(PRInt16 navType, PRInt32 pageNum)
 
 nsresult EphyBrowser::GetSHistory (nsISHistory **aSHistory)
 {
-	nsresult result;
-
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsIWebNavigation> ContentNav = do_QueryInterface (mWebBrowser);
 	NS_ENSURE_TRUE (ContentNav, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsISHistory> SessionHistory;
-	result = ContentNav->GetSessionHistory (getter_AddRefs (SessionHistory));
+	ContentNav->GetSessionHistory (getter_AddRefs (SessionHistory));
 	NS_ENSURE_TRUE (SessionHistory, NS_ERROR_FAILURE);
 
 	*aSHistory = SessionHistory.get();
@@ -413,7 +394,7 @@ nsresult EphyBrowser::Destroy ()
 
       	mWebBrowser = nsnull;
 	mDOMWindow = nsnull;
-	mEventReceiver = nsnull;
+	mEventTarget = nsnull;
 
 	mInitialized = PR_FALSE;
 
@@ -430,10 +411,11 @@ nsresult EphyBrowser::GoToHistoryIndex (PRInt16 index)
 	return ContentNav->GotoIndex (index);
 }
 
+#if (!MOZILLA_IS_BRANCH (1, 7) || !MOZILLA_CHECK_VERSION3 (1, 7, 3)) && !MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 3)
 /* Workaround for broken reload with frames, see mozilla bug
  * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
  */
-nsresult EphyBrowser::Reload (PRUint32 flags)
+nsresult EphyBrowser::Reload (ReloadType flags)
 {
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
@@ -467,6 +449,7 @@ nsresult EphyBrowser::Reload (PRUint32 flags)
 
 	return webNavigation->Reload (reloadFlags);
 }
+#endif
 
 nsresult EphyBrowser::SetZoom (float aZoom)
 {
@@ -513,8 +496,6 @@ nsresult EphyBrowser::GetDocument (nsIDOMDocument **aDOMDocument)
 
 nsresult EphyBrowser::GetTargetDocument (nsIDOMDocument **aDOMDocument)
 {
-	nsresult result;
-
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
 	/* Use the current target document */
@@ -532,9 +513,10 @@ nsresult EphyBrowser::GetTargetDocument (nsIDOMDocument **aDOMDocument)
 	webBrowserFocus = do_QueryInterface (mWebBrowser);
 	NS_ENSURE_TRUE (webBrowserFocus, NS_ERROR_FAILURE);
 
+	nsresult rv;
 	nsCOMPtr<nsIDOMWindow> DOMWindow;
-	result = webBrowserFocus->GetFocusedWindow (getter_AddRefs(DOMWindow));
-	if (NS_SUCCEEDED(result) && DOMWindow)
+	rv = webBrowserFocus->GetFocusedWindow (getter_AddRefs(DOMWindow));
+	if (NS_SUCCEEDED (rv) && DOMWindow)
 	{
 		return DOMWindow->GetDocument (aDOMDocument);
 	}
@@ -570,9 +552,9 @@ nsresult EphyBrowser::GetSHTitleAtIndex (PRInt32 index, PRUnichar **title)
 					 getter_AddRefs (he));
 	NS_ENSURE_TRUE (he, NS_ERROR_FAILURE);
 
-	nsresult result;
-	result = he->GetTitle (title);
-	NS_ENSURE_TRUE (NS_SUCCEEDED (result) && title, NS_ERROR_FAILURE);
+	nsresult rv;
+	rv = he->GetTitle (title);
+	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && title, NS_ERROR_FAILURE);
 
 	return NS_OK;
 }
@@ -594,9 +576,9 @@ nsresult EphyBrowser::GetSHUrlAtIndex (PRInt32 index, nsACString &url)
 	he->GetURI (getter_AddRefs(uri));
 	NS_ENSURE_TRUE (uri, NS_ERROR_FAILURE);
 
-	nsresult result;
-	result = uri->GetSpec(url);
-	NS_ENSURE_TRUE (NS_SUCCEEDED (result) && url.Length(), NS_ERROR_FAILURE);
+	nsresult rv;
+	rv = uri->GetSpec(url);
+	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && url.Length(), NS_ERROR_FAILURE);
 
 	return NS_OK;
 }
@@ -738,8 +720,9 @@ nsresult EphyBrowser::GetForcedEncoding (nsACString &encoding)
 	nsCOMPtr<nsIMarkupDocumentViewer> mdv = do_QueryInterface(contentViewer);
 	NS_ENSURE_TRUE (mdv, NS_ERROR_FAILURE);
 
-	nsresult result = mdv->GetForceCharacterSet (encoding);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
+	nsresult rv;
+	rv = mdv->GetForceCharacterSet (encoding);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	return NS_OK;
 }
@@ -933,9 +916,9 @@ nsresult EphyBrowser::GetHasModifiedForms (PRBool *modified)
 		nsCOMPtr<nsIDOMDocument> domDoc;
 		contentViewer->GetDOMDocument (getter_AddRefs (domDoc));
 
-		nsresult result;
-		result = GetDocumentHasModifiedForms (domDoc, &numTextFields, &hasTextArea);
-		if (NS_SUCCEEDED (result) &&
+		nsresult rv;
+		rv = GetDocumentHasModifiedForms (domDoc, &numTextFields, &hasTextArea);
+		if (NS_SUCCEEDED (rv) &&
 		    (numTextFields >= NUM_MODIFIED_TEXTFIELDS_REQUIRED || hasTextArea))
 		{
 			*modified = PR_TRUE;
