@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.91 2004/08/08 18:11:56 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.92 2004/08/19 17:48:43 marco Exp $
  */
 
 #include "mozilla-config.h"
@@ -451,6 +451,9 @@ init_services (MozillaEmbedSingle *single)
 	mozilla_init_home ();
 	mozilla_init_profile ();
 
+	/* Set mozilla binary path */
+	gtk_moz_embed_set_comp_path (MOZILLA_HOME);
+
 	/* Fire up the beast */
 	gtk_moz_embed_push_startup ();
 
@@ -499,6 +502,8 @@ mozilla_embed_single_init (MozillaEmbedSingle *mes)
 	{
 		GtkWidget *dialog;
 
+		/* FIXME Kill references to MOZILLA_FIVE_HOME
+		   when string freeze is over */
 		dialog = gtk_message_dialog_new
 			(NULL,
                          GTK_DIALOG_MODAL,
