@@ -17,8 +17,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ *  $Id: ephy-state.c,v 1.27 2004/03/17 09:02:35 marco Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-state.h"
 #include "ephy-file-helpers.h"
 #include "ephy-node-db.h"
@@ -130,8 +135,16 @@ ephy_state_window_set_size (GtkWidget *window, EphyNode *node)
 
 	if (size)
 	{
-		gtk_window_set_default_size
-			(GTK_WINDOW (window), width, height);
+		GdkScreen *screen;
+		int screen_width, screen_height;
+
+		screen = gdk_screen_get_default ();
+		screen_width = gdk_screen_get_width (screen);
+		screen_height = gdk_screen_get_height (screen);
+
+		gtk_window_set_default_size (GTK_WINDOW (window),
+					     MIN (width, screen_width),
+					     MIN (height, screen_height));
 	}
 
 	if (maximize)
