@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.76.4.3 2004/04/18 14:17:07 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.85 2004/08/08 15:33:26 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,13 +37,17 @@
 #include "ephy-langs.h"
 #include "ephy-encodings.h"
 #include "ephy-debug.h"
-#include "ephy-ellipsizing-label.h"
+#include "ephy-label.h"
 #include "ephy-file-chooser.h"
 #include "ephy-file-helpers.h"
 #include "ephy-tree-model-node.h"
 #include "ephy-tree-model-sort.h"
 
 #include <glib/gi18n.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkcelllayout.h>
+#include <gtk/gtktreeselection.h>
 #include <gtk/gtkframe.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
@@ -63,8 +67,6 @@ static void prefs_dialog_class_init	(PrefsDialogClass *klass);
 static void prefs_dialog_init		(PrefsDialog *pd);
 
 /* Glade callbacks */
-void prefs_proxy_auto_url_reload_cb		(GtkWidget *button,
-						 EphyDialog *dialog);
 void prefs_clear_cache_button_clicked_cb	(GtkWidget *button,
 						 gpointer data);
 void prefs_dialog_response_cb			(GtkDialog *widget,
@@ -601,7 +603,7 @@ create_node_combo (EphyDialog *dialog,
 
 	combo = GTK_COMBO_BOX (ephy_dialog_get_control (dialog, properties[prop].id));
 
-	nodemodel = ephy_tree_model_node_new (node, NULL);
+	nodemodel = ephy_tree_model_node_new (node);
 
 	title_col = ephy_tree_model_node_add_prop_column
 			(nodemodel, G_TYPE_STRING, EPHY_NODE_ENCODING_PROP_TITLE_ELIDED);
@@ -1132,9 +1134,8 @@ create_download_path_label (EphyDialog *dialog)
 	button = ephy_dialog_get_control (dialog, properties[DOWNLOAD_PATH_BUTTON_PROP].id);
 	
 	dir = get_download_button_label ();
-	label = ephy_ellipsizing_label_new (dir);
-	ephy_ellipsizing_label_set_mode ((EphyEllipsizingLabel*)label,
-					  EPHY_ELLIPSIZE_START);
+	label = ephy_label_new (dir);
+	ephy_label_set_ellipsize (EPHY_LABEL (label), PANGO_ELLIPSIZE_START);
 	gtk_container_add (GTK_CONTAINER (button), label);
 	g_free (dir);
 	gtk_widget_show (label);
@@ -1295,8 +1296,7 @@ download_path_response_cb (GtkDialog *fc, gint response, EphyDialog *dialog)
 
 			button = ephy_dialog_get_control (dialog, properties[DOWNLOAD_PATH_BUTTON_PROP].id);
 			label = get_download_button_label ();
-			ephy_ellipsizing_label_set_text ((EphyEllipsizingLabel*) GTK_BIN (button)->child,
-							  label);
+			ephy_label_set_text (EPHY_LABEL (GTK_BIN (button)->child), label);
 
 			g_free (dir);
 			g_free (label);
@@ -1321,8 +1321,10 @@ prefs_download_path_button_clicked_cb (GtkWidget *button,
 		fc = ephy_file_chooser_new (_("Select a directory"),
 					    GTK_WIDGET (parent),
 					    GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-					    NULL);
-	
+					    NULL, EPHY_FILE_FILTER_NONE);
+		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (fc),
+						     g_get_home_dir ());
+
 		g_signal_connect (GTK_DIALOG (fc), "response",
 				    G_CALLBACK (download_path_response_cb),
 				    dialog);
