@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: toolbar.c,v 1.80 2004/07/02 21:59:32 chpe Exp $
+ *  $Id: toolbar.c,v 1.81 2004/08/09 18:41:49 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -470,7 +470,7 @@ toolbar_new (EphyWindow *window)
 {
 	return EPHY_TOOLBAR (g_object_new (EPHY_TYPE_TOOLBAR,
 					   "window", window,
-					   "MenuMerge", window->ui_merge,
+					   "ui-manager", window->ui_merge,
 					   NULL));
 }
 
